@@ -25,7 +25,7 @@ SetDefaultAppOpt <- function(clean = TRUE)
         DEenv$AppOpt <- list()
 
     if(is.null(DEenv$AppOpt$bckopen))
-        DEenv$AppOpt$bckopen <- TRUE
+        DEenv$AppOpt$bckopen <- FALSE
     if(is.null(DEenv$AppOpt$bcklast))
         DEenv$AppOpt$bcklast <- FALSE
     if(is.null(DEenv$AppOpt$nbcks))
@@ -99,7 +99,7 @@ GetAppOpt <- function()
 
 SetDefaultProjOpt <- function()
 {
-    po <- list("droplist" = FALSE, "emptycell" = FALSE, "missv" = "NA")
+    po <- list("droplist" = FALSE, "emptycell" = FALSE, "missv" = "NA", "editwidth" = 25)
 
     # Do not reset some options:
     if(!is.null(DEenv$ProjOpt$size.roww))
@@ -196,6 +196,8 @@ OpenProject <- function()
         SetDefaultProjOpt()
 
     # The Project options might have been saved by an outdated version of DataEntry
+    if(is.null(DEenv$editwidth))
+        DEenv$ProjOpt$editwidth <- 25
     if(is.null(DEenv$ProjOpt$droplist))
         DEenv$AppOpt$droplist <- FALSE
     if(is.null(DEenv$ProjOpt$emptycell))
